//
//  DistribuidoresTableViewController.swift
//  PromoHoreca
//
//  Created by Mireia Izquierdo aymerich on 26/12/18.
//  Copyright © 2018 Mireia Izquierdo aymerich. All rights reserved.
//

import UIKit

class DistribuidoresTableViewController: UITableViewController {

    private var activityIndicador:UIActivityIndicatorView = UIActivityIndicatorView()
    lazy var arefreshControl: UIRefreshControl = {
        let refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action:
            #selector(DistribuidoresTableViewController.handleRefresh(_:)),
                                 for: UIControl.Event.valueChanged)
        refreshControl.tintColor = UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
        
        return refreshControl
    }()
    var distris : [Distribuidores] = []
    var fabricanteID:String = ""
    override func viewDidLoad() {
        super.viewDidLoad()

        let tbvc = tabBarController as! idTabBar
        fabricanteID = tbvc.myID
        
        self.distris.removeAll()
        self.getDistribuidores()
        
        self.activityIndicador.center=self.view.center
        self.activityIndicador.autoresizingMask = [.flexibleBottomMargin, .flexibleLeftMargin, .flexibleWidth, .flexibleRightMargin, .flexibleTopMargin, .flexibleHeight, .flexibleBottomMargin]
        self.activityIndicador.hidesWhenStopped = true
        self.activityIndicador.style = .gray
        self.view.addSubview(self.activityIndicador)
        self.activityIndicador.startAnimating()
        self.tableView.addSubview(arefreshControl)
        
        self.tableView.tableFooterView = UIView()
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        self.distris.removeAll()
        self.getDistribuidores()
        self.tableView.reloadData()
    }
    
    override func viewDidAppear(_ animated: Bool) {
        self.distris.removeAll()
        self.getDistribuidores()
        self.tableView.reloadData()
        
    }
    
    
    @objc func handleRefresh(_ refreshControl: UIRefreshControl) {
        self.distris.removeAll()
        self.getDistribuidores()
        self.tableView.reloadData()
        refreshControl.endRefreshing()
    }

    // MARK: - Table view data source

    override func numberOfSections(in tableView: UITableView) -> Int {
        // #warning Incomplete implementation, return the number of sections
        return 1
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if distris.count == 0{
            self.activityIndicador.stopAnimating()
        }
        return distris.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "DistribuidoresTableViewCell", for: indexPath) as! DistribuidoresTableViewCell
        
        
        // Configure the cell...
        cell.distribuidor = distris[indexPath.row]
        cell.dNombre.text = distris[indexPath.row].Nombre
        cell.dZona.text = "Zona: " + distris[indexPath.row].Zona
        cell.dDireccion.text = distris[indexPath.row].Direccion + ", " + distris[indexPath.row].CPostal + " " + distris[indexPath.row].Ciudad
        cell.dTelefono.text = distris[indexPath.row].Telefono
        
        
        return cell
    }

    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "newDist" {
            let vc = segue.destination as? NewDistribuidorViewController
            vc!.fabricanteID = self.fabricanteID
        }
        else if segue.identifier=="detalleDistSegue"
        {
            let vc = segue.destination as? DetalleDistriViewController
            vc!.distri = distris[(tableView.indexPathForSelectedRow?.row)!]
        }
    }
    
    func getDistribuidores(){
        UIApplication.shared.beginIgnoringInteractionEvents()
        self.activityIndicador.startAnimating()
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetDistribuidor"
        let idFabItem = URLQueryItem(name: "idFabricante", value: fabricanteID)
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let error = responseError {
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener los distribuidores.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                } else if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    guard let distribuidores = try? JSONDecoder().decode([String:[Distribuidores]].self, from: jsonData) else {
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        let alert = UIAlertController(title: "Error", message: "No se han podido obtener los distribuidores.", preferredStyle: UIAlertController.Style.alert)
                        alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                        alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                        self.present(alert, animated: true, completion: nil)
                        return
                    }
                    if (distribuidores.count>0){
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        self.distris.removeAll()
                        for distri in distribuidores{
                            for value in distri.value{
                                self.reload(distribuidor: value)

                            }
                            
                        }
                        
                    }
                    
                } else {
                    let error = NSError(domain: "", code: 0, userInfo: [NSLocalizedDescriptionKey : "Data was not retrieved from request"]) as Error
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                }
            }
        }
        
        task.resume()
    }
    
    @IBAction func returnActionForSegue(segue: UIStoryboardSegue) {
    }

    func reload(distribuidor:Distribuidores){
        DispatchQueue.main.async{
            if !(self.distris.contains(where: { $0.idDistribuidor == distribuidor.idDistribuidor })){
                self.distris.append(distribuidor)
            }
            self.tableView.reloadData()
        }
    }
}
