//
//  PedidosEstabTableViewController.swift
//  PromoHoreca
//
//  Created by Mireia Izquierdo aymerich on 28/12/18.
//  Copyright © 2018 Mireia Izquierdo aymerich. All rights reserved.
//

import UIKit

class PedidosEstabTableViewController: UITableViewController {
    private var activityIndicador:UIActivityIndicatorView = UIActivityIndicatorView()
    lazy var arefreshControl: UIRefreshControl = {
        let refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action:
            #selector(PedidosEstabTableViewController.handleRefresh(_:)),
                                 for: UIControl.Event.valueChanged)
        refreshControl.tintColor = UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
        
        return refreshControl
    }()
    var establecimientoId:String = ""
    var pedidos : [Pedidos] = []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        let tbvc = tabBarController as! idTabBar
        establecimientoId = tbvc.myID
        self.getPedidos()
        self.activityIndicador.center=self.view.center
        self.activityIndicador.autoresizingMask = [.flexibleBottomMargin, .flexibleLeftMargin, .flexibleWidth, .flexibleRightMargin, .flexibleTopMargin, .flexibleHeight, .flexibleBottomMargin]
        self.activityIndicador.hidesWhenStopped = true
        self.activityIndicador.style = .gray
        self.view.addSubview(self.activityIndicador)
        self.activityIndicador.startAnimating()
        self.tableView.addSubview(arefreshControl)
        
        self.tableView.tableFooterView = UIView()
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        self.getPedidos()
        self.tableView.reloadData()
    }
    
    override func viewDidAppear(_ animated: Bool) {
        
        self.getPedidos()
        self.tableView.reloadData()
        
    }
    
    
    @objc func handleRefresh(_ refreshControl: UIRefreshControl) {
        
        self.getPedidos()
        self.tableView.reloadData()
        refreshControl.endRefreshing()
    }
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        // #warning Incomplete implementation, return the number of sections
        return 1
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if pedidos.count == 0{
            self.activityIndicador.stopAnimating()
        }
        return pedidos.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "PedidosEstabTableViewCell", for: indexPath) as! PedidosEstabTableViewCell
        
        
        // Configure the cell...
        cell.pedido = pedidos[indexPath.row]
        cell.nomPromo.text = pedidos[indexPath.row].PromocionNombre
        cell.numpedido.text = "#" + pedidos[indexPath.row].idPedido
        cell.cantidad.text =  "Cantidad: " + pedidos[indexPath.row].Cantidad
        cell.importe.text = "Importe: " + pedidos[indexPath.row].Importe + "€"
        cell.distribuidor.text = "Distribuidor: " + pedidos[indexPath.row].DistNombre
        cell.fabricante.text = "Fabricante: " + pedidos[indexPath.row].FabNombre

        return cell
    }
    
    func getPedidos(){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPedidosEstab"
        let idFabItem = URLQueryItem(name: "idEstablecimiento", value: establecimientoId)
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let error = responseError {
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener los pedidos.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                } else if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    guard let pedidosl = try? JSONDecoder().decode([String:[Pedidos]].self, from: jsonData) else {
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        let alert = UIAlertController(title: "Error", message: "No se han podido obtener los pedidos.", preferredStyle: UIAlertController.Style.alert)
                        alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                        alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                        self.present(alert, animated: true, completion: nil)
                        return
                    }
                    if (pedidosl.count>0){
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        self.pedidos.removeAll()
                        for pedid in pedidosl{
                            for value in pedid.value{
                                self.reload(ped: value)
                            }
                            
                        }
                        
                    }
                    
                } else {
                    let error = NSError(domain: "", code: 0, userInfo: [NSLocalizedDescriptionKey : "Data was not retrieved from request"]) as Error
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener los pedidos.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                }
            }
        }
        
        task.resume()
    }
    
    @IBAction func returnActionForSegue(segue: UIStoryboardSegue) {
    }
    
    func reload(ped:Pedidos){
        DispatchQueue.main.async{
            if !(self.pedidos.contains(where: { $0.idPedido == ped.idPedido })){
                self.pedidos.append(ped)
            }
            self.tableView.reloadData()
        }
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "detallePedido"{
            let vc = segue.destination as? DetallePedidoEstabTableViewController
            vc!.pedido = pedidos[(tableView.indexPathForSelectedRow?.row)!]
        }
    }
}
