//
//  PromoEstabTableViewController.swift
//  PromoHoreca
//
//  Created by Mireia Izquierdo aymerich on 30/11/18.
//  Copyright © 2018 Mireia Izquierdo aymerich. All rights reserved.
//

import UIKit

class PromoEstabTableViewController: UITableViewController {

    private var activityIndicador:UIActivityIndicatorView = UIActivityIndicatorView()
    lazy var arefreshControl: UIRefreshControl = {
        let refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action:
            #selector(PromoEstabTableViewController.handleRefresh(_:)),
                                 for: UIControl.Event.valueChanged)
        refreshControl.tintColor = UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
        
        return refreshControl
    }()
    var promos : [Promociones] = []
    var establecimientoID:String=""
    var commentsDict: [Int: Int] = [:]
    var likesDict: [Int: Int] = [:]
    
    override func viewDidLoad() {
        super.viewDidLoad()
        let tbvc = tabBarController as! idTabBar
        establecimientoID = tbvc.myID
        self.promos.removeAll()
        getPromociones()
        self.activityIndicador.center=self.view.center
        self.activityIndicador.autoresizingMask = [.flexibleBottomMargin, .flexibleLeftMargin, .flexibleWidth, .flexibleRightMargin, .flexibleTopMargin, .flexibleHeight, .flexibleBottomMargin]
        self.activityIndicador.hidesWhenStopped = true
        self.activityIndicador.style = .gray
        self.view.addSubview(self.activityIndicador)
        self.activityIndicador.startAnimating()
        self.tableView.addSubview(arefreshControl)
        
        self.tableView.tableFooterView = UIView()

    }
    
    override func viewWillAppear(_ animated: Bool) {
        let tbvc = tabBarController as! idTabBar
        establecimientoID = tbvc.myID
        self.promos.removeAll()
        getPromociones()
        self.tableView.reloadData()
        
    }

    override func viewDidAppear(_ animated: Bool) {
        let tbvc = tabBarController as! idTabBar
        establecimientoID = tbvc.myID
        self.promos.removeAll()
        getPromociones()
        self.tableView.reloadData()
        
    }
    // MARK: - Table view data source

    override func numberOfSections(in tableView: UITableView) -> Int {
        // #warning Incomplete implementation, return the number of sections
        return 1
    }

    @objc func handleRefresh(_ refreshControl: UIRefreshControl) {
        self.promos.removeAll()
        getPromociones()
        self.tableView.reloadData()
        refreshControl.endRefreshing()
    }
    
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if promos.count == 0{
            self.activityIndicador.stopAnimating()
        }
        return promos.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "PromoEstabTableViewCell", for: indexPath) as! PromoEstabTableViewCell
        
        // Configure the cell...
        cell.promocion = promos[indexPath.row]
        cell.nombre.text = promos[indexPath.row].Nombre
        cell.fecha.text = "Hasta: " + promos[indexPath.row].FechaCaducidad
        cell.precio.text = String(promos[indexPath.row].PrecioUnitario) + " €/Unidad"
        cell.tipoprod.text = "Tipo Producto: " + promos[indexPath.row].TipoProducto
        cell.ldesc.text = promos[indexPath.row].Descripcion
        cell.lfab.text = promos[indexPath.row].NombreFabricante
        if let com =  self.commentsDict[promos[indexPath.row].idPromocion], self.commentsDict.count > 0{
            cell.numCom.text = String(com)
        }
        if let likes =  self.likesDict[promos[indexPath.row].idPromocion], self.likesDict.count > 0{
            cell.numLikes.text = String(likes)
        }
        
        
        return cell
    }
    
    func getPromoNumComments(numPromo:Int){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoNumComment"
        let idFabItem = URLQueryItem(name: "idPromocion", value: String(numPromo))
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    let comments = try? JSONDecoder().decode(Count.self, from: jsonData)
                    self.reloadNumC(count: (comments?.count)!, numPromo: numPromo)
                    
                    
                    
                }
            }
        }
        
        task.resume()
    }
    
    func getPromoNumLikes(numPromo:Int){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoNumLikes"
        let idFabItem = URLQueryItem(name: "idPromocion", value: String(numPromo))
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    let comments = try? JSONDecoder().decode(Count.self, from: jsonData)
                    self.reloadNumL(count: (comments?.count)!, numPromo: numPromo)
                    
                    
                    
                }
            }
        }
        
        task.resume()
    }
    

    
    func getPromociones(){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoEstab"
        let idFabItem = URLQueryItem(name: "idEstablecimiento", value: establecimientoID )
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let error = responseError {
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                } else if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    guard let promociones = try? JSONDecoder().decode([String:[Promociones]].self, from: jsonData) else {
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                        alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                        alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                        self.present(alert, animated: true, completion: nil)
                        return
                    }
                    if (promociones.count>0){
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        self.promos.removeAll()
                        for promo in promociones{
                            for value in promo.value{
                                /*self.promos.append(value)
                                self.getPromoNumComments(numPromo: value.idPromocion)
                                self.getPromoNumLikes(numPromo: value.idPromocion)*/
                                self.reload(promo: value)
                                
                            }
                            
                        }
                        
                    }
                    
                } else {
                    let error = NSError(domain: "", code: 0, userInfo: [NSLocalizedDescriptionKey : "Data was not retrieved from request"]) as Error
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                }
            }
        }
        
        task.resume()
    }
    
    @IBAction func returnActionForSegue(segue: UIStoryboardSegue) {
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        if segue.identifier=="detalleEstabSegue"
        {
            let vc = segue.destination as? DetalleEstabTableViewController
            vc!.promo = promos[(tableView.indexPathForSelectedRow?.row)!]
            if let com =  self.commentsDict[promos[(tableView.indexPathForSelectedRow?.row)!].idPromocion], self.commentsDict.count > 0{
                vc!.numcomments = String(com)
            }
            if let likes =  self.likesDict[promos[(tableView.indexPathForSelectedRow?.row)!].idPromocion], self.likesDict.count > 0{
                vc!.numlikes = String(likes)
            }
            vc!.establecimientoId=self.establecimientoID
            
            
        }
    }
    
    func reload(promo:Promociones){
        DispatchQueue.main.async{
            if !(self.promos.contains(where: { $0.idPromocion == promo.idPromocion })){
                self.promos.append(promo)
            }
            
            self.getPromoNumComments(numPromo: promo.idPromocion)
            self.getPromoNumLikes(numPromo: promo.idPromocion)
            self.tableView.reloadData()
        }
    }
    
    func reloadNumL(count:Int,numPromo:Int){
        DispatchQueue.main.async{
            self.likesDict.updateValue(((count)), forKey: numPromo)
            self.tableView.reloadData()
        }
    }
    
    func reloadNumC(count:Int,numPromo:Int){
        DispatchQueue.main.async{
            self.commentsDict.updateValue(((count)), forKey: numPromo)
            self.tableView.reloadData()
        }
    }



}
