//
//  PromoFabTableViewController.swift
//  PromoHoreca
//
//  Created by Mireia Izquierdo aymerich on 30/11/18.
//  Copyright © 2018 Mireia Izquierdo aymerich. All rights reserved.
//

import UIKit
import AVFoundation
import AVKit

class PromoFabTableViewController: UITableViewController {
    
    private var activityIndicador:UIActivityIndicatorView = UIActivityIndicatorView()
    lazy var arefreshControl: UIRefreshControl = {
        let refreshControl = UIRefreshControl()
        refreshControl.addTarget(self, action:
            #selector(PromoFabTableViewController.handleRefresh(_:)),
                                 for: UIControl.Event.valueChanged)
        refreshControl.tintColor = UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
        
        return refreshControl
    }()
    

    var com = 0
    var ped = 0
    var likes = 0
    var fabricanteID:String = ""
    var promos : [Promocion] = []
    var commentsDict: [Int: Int] = [:]
    var likesDict: [Int: Int] = [:]
    var pedDict: [Int: Int] = [:]
    
    override func viewDidLoad() {
        super.viewDidLoad()
        let tbvc = tabBarController as! idTabBar
        fabricanteID = tbvc.myID
        self.getPromociones()
        self.activityIndicador.center=self.view.center
        self.activityIndicador.autoresizingMask = [.flexibleBottomMargin, .flexibleLeftMargin, .flexibleWidth, .flexibleRightMargin, .flexibleTopMargin, .flexibleHeight, .flexibleBottomMargin]
        self.activityIndicador.hidesWhenStopped = true
        self.activityIndicador.style = .gray
        self.view.addSubview(self.activityIndicador)
        self.activityIndicador.startAnimating()
        self.tableView.addSubview(arefreshControl)
        
        self.tableView.tableFooterView = UIView()
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        self.getPromociones()
        self.tableView.reloadData()
    }
    
   override func viewDidAppear(_ animated: Bool) {
        
        self.getPromociones()
        self.tableView.reloadData()
        
    }
    
    
   @objc func handleRefresh(_ refreshControl: UIRefreshControl) {
        
        self.getPromociones()
        self.tableView.reloadData()
        refreshControl.endRefreshing()
    }
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        // #warning Incomplete implementation, return the number of sections
        return 1
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if promos.count == 0{
            self.activityIndicador.stopAnimating()
        }
        return promos.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "PromocionFabTableViewCell", for: indexPath) as! PromocionFabTableViewCell
        
        
        // Configure the cell...
        cell.promocion = promos[indexPath.row]
        cell.nombre.text = promos[indexPath.row].Nombre
        cell.caducidad.text = "Hasta: " + promos[indexPath.row].FechaCaducidad
        cell.precio.text = String(promos[indexPath.row].PrecioUnitario) + " €/Unidad"
        if let com =  self.commentsDict[promos[indexPath.row].idPromocion], self.commentsDict.count > 0{
            cell.numComents.text = String(com)
        }
        if let likes =  self.likesDict[promos[indexPath.row].idPromocion], self.likesDict.count > 0{
            cell.numLikes.text = String(likes)
        }
        if let ped =  self.pedDict[promos[indexPath.row].idPromocion], self.pedDict.count > 0{
            cell.numPedidos.text = String(ped)
        }
        
       
        cell.tipoprod.text = "Tipo Producto: " + promos[indexPath.row].TipoProducto
        if(promos[indexPath.row].Zona.components(separatedBy: ",").count == 7){
           cell.zona.text = "Zona: TODAS"
        } else {
            cell.zona.text = "Zona: " + promos[indexPath.row].Zona.replacingOccurrences(of: "[", with: "").replacingOccurrences(of: "]", with: "").replacingOccurrences(of: "\"", with: "")
        }
        
        if(promos[indexPath.row].TipoEstablecimiento.components(separatedBy: ",").count == 9)
        {
            cell.tipo.text = "Tipo establecimiento: TODOS"
        } else {
            cell.tipo.text = "Tipo establecimiento: " + promos[indexPath.row].TipoEstablecimiento.replacingOccurrences(of: "[", with: "").replacingOccurrences(of: "]", with: "").replacingOccurrences(of: "\"", with: "")
        }
        
        let dateFormatter = DateFormatter()
        dateFormatter.dateFormat = "dd'-'MM'-'yyyy'"
        let date = dateFormatter.date(from: promos[indexPath.row].FechaCaducidad)
        let now = Date()
        if (date == now || date! > now){
            cell.status.text = "ACTIVA"
            cell.status.textColor = UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
        }else{
            cell.status.text = "INACTIVA"
            cell.status.textColor = UIColor.red
        }
        
    
        return cell
    }
    
    
    func getPromoNumComments(numPromo:Int){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoNumComment"
        let idFabItem = URLQueryItem(name: "idPromocion", value: String(numPromo))
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    let comments = try? JSONDecoder().decode(Count.self, from: jsonData)
                    if (comments?.count != nil){
                        self.commentsDict.updateValue(((comments?.count)!), forKey: numPromo)
                    }else{
                        self.commentsDict.updateValue(0, forKey: numPromo)
                    }
                        
                    
                    
                }
            }
        }
        
        task.resume()
    }
    
    func getPromoNumLikes(numPromo:Int) {
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoNumLikes"
        let idFabItem = URLQueryItem(name: "idPromocion", value: String(numPromo))
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    let comments = try? JSONDecoder().decode(Count.self, from: jsonData)
                    if (comments?.count != nil){
                        self.likesDict.updateValue(((comments?.count)!), forKey: numPromo)
                    }else{
                        self.likesDict.updateValue(0, forKey: numPromo)
                    }
                    
                    
                    
                }
            }
        }
        
        task.resume()
    }
    
    func getPromoNumPedidos(numPromo:Int) {
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoNumPed"
        let idFabItem = URLQueryItem(name: "idPromocion", value: String(numPromo))
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    let comments = try? JSONDecoder().decode(Count.self, from: jsonData)
                    if (comments?.count != nil){
                        self.pedDict.updateValue(((comments?.count)!), forKey: numPromo)
                    }else{
                        self.pedDict.updateValue(0, forKey: numPromo)
                    }
                    
                    
                    
                }
            }
        }
        
        task.resume()
    }
    
    func getPromociones(){
        var urlComponents = URLComponents()
        urlComponents.scheme = "http"
        urlComponents.host = "ec2-52-47-86-31.eu-west-3.compute.amazonaws.com"
        urlComponents.path = "/GetPromoFab"
        let idFabItem = URLQueryItem(name: "idFabricante", value: fabricanteID)
        urlComponents.queryItems = [idFabItem]
        guard let url = urlComponents.url else { fatalError("Could not create URL from components") }
        
        var request = URLRequest(url: url)
        request.httpMethod = "GET"
        
        let config = URLSessionConfiguration.default
        let session = URLSession(configuration: config)
        let task = session.dataTask(with: request) { (responseData, response, responseError) in
            DispatchQueue.main.async {
                if let error = responseError {
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                } else if let jsonData = responseData {
                    // Now we have jsonData, Data representation of the JSON returned to us
                    // from our URLRequest...
                    print(jsonData.description)
                    guard let promociones = try? JSONDecoder().decode([String:[Promocion]].self, from: jsonData) else {
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                        alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                        alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                        self.present(alert, animated: true, completion: nil)
                        return
                    }
                    if (promociones.count>0){
                        UIApplication.shared.endIgnoringInteractionEvents()
                        self.activityIndicador.stopAnimating()
                        self.promos.removeAll()
                        for promo in promociones{
                            for value in promo.value{
                                self.promos.append(value)
                                self.getPromoNumComments(numPromo: value.idPromocion)
                                self.getPromoNumLikes(numPromo: value.idPromocion)
                                self.getPromoNumPedidos(numPromo: value.idPromocion)
                            }
                            
                        }
                        
                    }
                 
                } else {
                    let error = NSError(domain: "", code: 0, userInfo: [NSLocalizedDescriptionKey : "Data was not retrieved from request"]) as Error
                    print(error)
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.activityIndicador.stopAnimating()
                    let alert = UIAlertController(title: "Error", message: "No se han podido obtener las promociones.", preferredStyle: UIAlertController.Style.alert)
                    alert.addAction(UIAlertAction(title: "OK", style: UIAlertAction.Style.default, handler: nil))
                    alert.view.tintColor=UIColor(red: 22.0/255.0, green: 170.0/255.0, blue: 93.0/255.0, alpha: 1.0)
                    self.present(alert, animated: true, completion: nil)
                }
            }
        }
        
        task.resume()
    }
    
    @IBAction func returnActionForSegue(segue: UIStoryboardSegue) {
    }
    
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        if segue.identifier=="detalleFabSegue"
        {
            let vc = segue.destination as? DetalleFabTableViewController
            vc!.promo = promos[(tableView.indexPathForSelectedRow?.row)!]
            if let com =  self.commentsDict[promos[(tableView.indexPathForSelectedRow?.row)!].idPromocion], self.commentsDict.count > 0{
                vc!.numcomments = String(com)
            }
            if let likes =  self.likesDict[promos[(tableView.indexPathForSelectedRow?.row)!].idPromocion], self.likesDict.count > 0{
                vc!.numlikes = String(likes)
            }
            if let ped =  self.pedDict[promos[(tableView.indexPathForSelectedRow?.row)!].idPromocion], self.pedDict.count > 0{
                vc!.numped = String(ped)
            }
            
            
        }
        else if segue.identifier=="addPromo"
        {
            let vc = segue.destination as? addPromoTableViewController
            vc!.idfab = fabricanteID
        }
    }
    
}
